@@ -8,6 +8,7 @@ fn use_develop_debug() {
     let array = vec!["a", "b", "c"];
     let title2 = "balabala...";
 
+    develop_debug!(output true);
     develop_debug!(title "example {}",title2);
     develop_debug!(step "do something...{}", say);
     develop_debug!(var x,say);
@@ -18,6 +19,7 @@ fn use_develop_debug() {
         "{}",
         "Use it just as you would with the `println!()` macro."
     );
+    develop_debug!(output false);
 }
 
 // Using the shortcut, print the same result as above.
@@ -28,6 +30,7 @@ fn use_develop_debug_shortcut() {
     let array = vec!["a", "b", "c"];
     let title2 = "balabala...";
 
+    dd____show!();
     dd___title!("example {}", title2);
     dd____step!("do something...{}", say);
     dd_____var!(x, say);
@@ -38,4 +41,5 @@ fn use_develop_debug_shortcut() {
         "{}",
         "Use it just as you would with the `println!()` macro."
     );
+    dd____hide!();
 }
